iterator

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Iterator

type Iterator interface {
	// Next returns the next item from the iterator. io.EOF is returned when no more items are left.
	Next() (item string, err error)
}

Iterator returns items

func NewListIterator

func NewListIterator(items []string) Iterator

NewListIterator returns a new iterator from a list of items.

func NewNoopIterator

func NewNoopIterator() Iterator

NewNoopIterator returns a new no-op iterator.

func NewReaderIterator

func NewReaderIterator(rd io.Reader, sep byte) Iterator

NewReaderIterator returns a new iterator from a reader.

Source Files

  • iterator.go

Jump to